/** 
 * @file   DFComm.h
 * @author Bernd Ottmann
 * @date   27.08.2003
 * @brief  Deklarationen der Exportroutinen.
 * @note   Die Auflistung der Routinen ist wie in der zugehoerigen Dokumentation.
 */
//////////////////////////////////////////////////////////////////////
#ifndef _DFCOMMIV_H_
#define _DFCOMMIV_H_

/** 
 @mainpage Dokumentation zur DFCommIV.
 <center> @code 

   ########################################################
   ##       |                   |                  |     ##
   ##                          \_/                       ##
   ##       |                 -(_)-                |  \  ##
   ##                          / \                    |\\##
   ##  /|   |                                      |  || ##
   ##/ ||                  _\|||/_                    || ##
   ##  ||   |               /_=_\                  |  || ##
   ##  ||                  ({}-{})                    || ##
   ##  ||   |+-----oOo-------(_)---------------+   |  || ##
   ## //     |                                 |      || ##
   ##/      ||          Datafox GmbH           |   |  || ##
   ##        |                                 |      || ##
   ##       |+-------------------------oOo-----+   |  || ##
   ##                     |  |~|  |                   || ##
   ##       |_ __ _ __ _ _|__| |__|_ __ _ __ _ __ _|  || ##
   ##      /               ||   ||                  \ || ##
   ##    /               .ooO   Ooo.                  \ \##
   ##  /                                                \##
   ########################################################

 @endcode </center>
 @author Bernd Ottmann
 @date   27.08.2003
*/

// ########################################################
// ###################### DEFINES #########################
// ########################################################

/**
 * Version der verwendeten DLL.
 * 
 * @todo Version der verwendeten DLL pruefen, um nur die enthaltenen Routinen zu 
 * importieren oder auch zu exportieren.
 */
#define COMMIV_VERSION          0x03000000

/**
 * Gibt export oder import der Routinen an. Siehe auch EXTERN_DECL.
 *
 * @todo Mit 1 im Quelltext vor #include zu definieren um die Routinen als Import zu erhalten.
 *
 * @code #define DFCOMM_EXPORT   1 @endcode
 */
#ifndef DFCOMMIV_EXPORT
	#define DFCOMMIV_EXPORT 0
#endif

#ifndef USE_PRIVATE
	#define USE_PRIVATE   0
#endif

// Eventuell fehlende typedefs ersetzen
#ifndef HANDLE
	#define HANDLE void*
#endif

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +------------+ EXPORTIERTE FUNKTIONEN +----------------+
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++

/**
 @def EXTERN_DECL Gibt den Praefix fuer Funktionen an. (Dekorierung und Export-, Importangabe)
*/

#if (DFCOMMIV_EXPORT)
	// Einzubindende Bibliotheken: Version.lib, WSock32.lib
	#define EXTERN_DECL         extern "C" __declspec(dllexport)
	// DllGetVersion
	#include "shlwapi.h"
#else
	#define EXTERN_DECL         extern "C" __declspec(dllimport)
#endif


// ########################################################
// ############## ALLGEMEINE FUNKTIONEN ###################
// ########################################################

#if (COMMIV_VERSION >= 0x03000000)

// ########################################################
/** 
 * @brief Oeffnet den Kanal.
 *
 * Die Funktion initialisiert je nach Typ die serielle oder TCP/IP - Verbindung.
 *
 * @param iChannelID Kommunikationskanalnummer.
 * @param iDeviceID  Geraeteidentifikationsnummer.
 * @param iType
 * @param szCommString
 * @param iCommValue
 * @param iCommTimeOut
 *
 * @return Kommunikationskanal geoeffnet.
 * @retval 1 Erfolgreich geoeffnet.
 * @retval 0 Fehler bei Initialisierung. Siehe DFGetLastError().
 */
EXTERN_DECL int __stdcall DFOpen(int iChannelID, int iDeviceID, int iType, char *szCommString, int iCommValue, int iCommTimeOut);

// ########################################################
/** 
 * @brief Schliessen des geoeffneten Kanals.
 *
 * Je nach dem Typ des Kanals wird entweder die serielle Schnittstelle oder
 * der Socket geschlossen.
 *
 * @param iChannelID Kommunikationskanalnummer.
 *
 * @return Keine.
 */
EXTERN_DECL int __stdcall DFClose(int iChannelID);

// ########################################################
/** 
 * @brief Gibt die zuletzt aufgetretene Fehlernummer zurueck.
 *
 * Funktionen die durch den Rueckgabewert ihre gescheiterte Ausfuehrung mitteilen legen
 * die Fehlernummer in einer Variablen ab, mit dieser Funktion kann diese Fehlernummer
 * abgerufen werden.
 *
 * @param iChannelID Kommunikationskanalnummer.
 *
 * @return Die im Kanal aufgetretene Fehlernummer.
 */
EXTERN_DECL int __stdcall DFGetLastError(int iChannelID);

// ########################################################
/** 
 * @brief Setzen einer Rueckruffunktion.
 *
 * Die Rueckruffunktion wird waehrend des Kommunikationsablaufs fortwaehrend 
 * aufgerufen und bietet die Moeglichkeit eines fruehzeitigen abbruches des selbigen.
 *
 * @param iChannelID Kommunikationskanalnummer.
 * @param CBFunction Zeiger auf die Rueckruffunktion oder 0 fuer abschalten.
 *
 * @return Keine.
 */
EXTERN_DECL int __stdcall DFSetCallback(int iChannelID, int (*CBFunction)());

// ########################################################
/** 
 * @brief Die Seriennummer aus dem Geraet lesen.
 *
 * Gibt die gelesene Seriennummer als Ganzzahl ueber Parameter zurueck.
 *
 * @param iChannelID Kommunikationskanalnummer.
 * @param iDeviceID  Busnummer des anzusprechenden Geraetes.
 * @param piSerialNumber Zeiger auf Variable welche die Seriennummer erhaelt.
 *
 * @return Ergebnis der Werteermittlung.
 * @retval 0 Wert konnte nicht ermittelt werden und Fehlercode wurde ueber piError abgelegt.
 * @retval 1 Seriennummer wurde ueber piSerialNum in Variable uebergeben.
 */
EXTERN_DECL int __stdcall DFGetSerialNumber(int iChannelID, int iDeviceID, int *piSerialNumber);

// ########################################################
/** 
 * @brief Setzt das uebergebene Datum und die Uhrzeit in dem Geraet.
 *
 * Das zuvor aufbereitete Datum mit Uhrzeit muss in einem speziellen Format
 * vorliegen, welches in der Dokumentation zur DLL beschrieben ist.
 *
 * @param iChannelID Kommunikationskanalnummer.
 * @param iDeviceID  Busnummer des anzusprechenden Geraetes.
 * @param pucTime    Zeiger auf Bytearray mit Werten fuer Datum und Uhrzeit.
 *
 * @return Ergebnis der Wertsetzung im Geraet.
 * @retval 0 Wert konnte nicht gesetz werden.
 * @retval 1 Wert wurde erfolgreich gesetzt.
 */
EXTERN_DECL int __stdcall DFSetTime(int iChannelID, int iDeviceID, int iDay, int iMonth, int iYear, int iHour, int iMinute, int iSecond);

// ########################################################
/** 
 * @brief Holt das Datum und die Uhrzeit aus dem Geraet.
 *
 * Das Datum mit Uhrzeit wird in einem speziellen Format
 * abgelegt, welches in der Dokumentation zur DLL beschrieben ist.
 *
 * @param iChannelID Kommunikationskanalnummer.
 * @param iDeviceID  Busnummer des anzusprechenden Geraetes.
 * @param pucTime    Zeiger auf Bytearray mit Werten fuer Datum und Uhrzeit.
 *
 * @return Ergebnis der Wertermittlung aus dem Geraet.
 * @retval 0 Wert konnte nicht ermittelt werden.
 * @retval 1 Wert wurde erfolgreich ermittelt.
 */
EXTERN_DECL int __stdcall DFGetTime(int iChannelID, int iDeviceID, int *piDay, int *piMonth, int *piYear, int *piHour, int *piMinute, int *piSecond);

// ########################################################
/** 
 * @brief Direktes schreiben einer Textnachricht.
 *
 * Der gesendete Text wird fuer eine bestimmbare Zeit und mit einer
 * eventuell akustischen Signalisierung auf der Anzeige ausgegeben. Die
 * Ausgabe ist vom Geraetezustand abhaengig.
 *
 * @param iComNum Kommunikationskanalnummer.
 * @param iBusNum Busnummer des anzusprechenden Geraetes.
 * @param ucDelayTime Anzeigedauer in Sekunden. 255 -> nicht automatisch wegblenden.
 * @param ucAction Ist fuer Eingriffe in die Bedienung vorgesehen.
 * @param ucAudio Meldung aktustisch untermalen.
 * @param szMessage Zeiger auf den anzuzeigenden Text.
 *
 * @return Ergebnis der Textsendung an Geraet.
 * @retval 0 Text konnte nicht geschrieben werden.
 * @retval 1 Text wurde erfolgreich geschrieben.
 */
EXTERN_DECL int __stdcall DFShowMessage(int iChannelID, int iDeviceID, unsigned char ucDelayTime, unsigned char ucAction, unsigned char ucAudio, char *szMessage);

#endif


// ########################################################
// ############## FUNKTIONEN FUER SETUP ###################
// ########################################################

#if (COMMIV_VERSION >= 0x03000000)

// ########################################################
/** 
 * @brief Uebertragen einer Setupdatei.
 *
 * Es wird versucht die angegebene Setupdatei in das Geraet zu uebertragen.
 *
 * @param iComNum Kommunikationskanalnummer.
 * @param iBusNum Busnummer des anzusprechenden Geraetes.
 * @param szFileName Zeiger auf die Zeichenfolge, welche den Pfad und/oder Dateinamen enthaelt.
 * @param piError Zeiger auf Variable die nach Fehler den Fehlercode erhaelt.
 *
 * @return Ergebnis der Ausfuehrung.
 * @retval 0 Funktion konnte nicht ausgefuehrt werden.
 * @retval 1 Funktion wurde erfolgreich ausgefuehrt.
 */
EXTERN_DECL int __stdcall DFUpload(int iChannelID, int iDeviceID, char *szFileName);

#endif


// ########################################################
// ############## FUNKTIONEN FUER DATEN ###################
// ########################################################



// ########################################################
// ############## FUNKTIONEN FUER LISTEN ##################
// ########################################################


// ########################################################
// ####### FUNKTIONEN FUER ZUTRITTSKONTROLLLISTEN #########
// ########################################################



// ########################################################
// ############# ** PRIVATE FUNKTIONEN ** #################
// ########################################################

// Funktionen sind nicht dokumentiert.
// Sie werden von AESetup oder Talk verwendet.
// Unterliegen evntl. Aenderungen.

#if (USE_PRIVATE)


#endif // USE_PRIVATE

#endif
